<?php
/*
Plugin Name: Harlem Shake Beta
Description: Harlem Shake your website with sound and animation after typing the Konami code for activation
Version: 0.1
Author: Rutger Hensel @rutger
License: GPL2
*/

/*  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
?><?php

wp_enqueue_script("jquery");

define( 'PLUGIN_NAME', 'Harlem Shake Beta');
define( 'PLUGIN_DIRECTORY', 'harlem-shake');

register_activation_hook(__FILE__, 'khs_activate');
register_deactivation_hook(__FILE__, 'khs_deactivate');
register_uninstall_hook(__FILE__, 'khs_uninstall');

// activating the default values
function khs_activate() {
    add_option('khs_dom_id_first', '');
}

// deactivating
function khs_deactivate() {
    // needed for proper deletion of every option
    delete_option('khs_dom_id_first');
}

// uninstalling
function khs_uninstall() {
    # delete all data stored
    delete_option('khs_dom_id_first');
}

// create custom plugin settings menu
add_action('admin_menu', 'khs_create_menu');
add_action('admin_init', 'khs_register_settings');

function khs_create_menu() {
    add_submenu_page( 'options-general.php', PLUGIN_NAME, PLUGIN_NAME, 'manage_options', PLUGIN_DIRECTORY, 'khs_settings_page' ); 
}

function khs_register_settings() {
    register_setting( 'khs-settings-group', 'khs_dom_id_first' );
}

function khs_settings_page() {
?>
    <div class="wrap">
    <h2><?=PLUGIN_NAME?></h2>

    <?php
        if ( ! isset( $_REQUEST['updated'] ) )
        {
            $_REQUEST['updated'] = false; // This checks whether the form has just been submitted.
        }

        if ( false !== $_REQUEST['updated'] )
        {
            echo '<div><p><strong>'._e( 'Options saved' ) . '</strong></p></div>';
        } // If the form has just been submitted, this shows the notification
    ?>

    <form method="post" action="options.php">
        <?php settings_fields('khs-settings-group'); ?>
        <table class="form-table">
            <tr valign="top">
                <th scope="row">Element ID of first element to animate (leave empty to autodetect).</th>
                <td>
                    <input type="text" name="khs_dom_id_first" value="<?php echo htmlentities(get_option('khs_dom_id_first'), ENT_QUOTES); ?>" />
                </td>
            </tr>
        </table>
        <?php submit_button(); ?>
        <p>
            To activate visit your page and use the Konami code: <strong>up up down down left right left right b a</strong>
        </p>
        <p>
            Make sure you use Google Chrome browser and make sure there are no javascript errors, otherwise it may not work.
        </p>
        <p>
            To learn more about Developer Tools on Google Chrome watch this <a href="https://www.youtube.com/watch?v=nOEw9iiopwI" target="_blank">video</a>.
        </p>
    </form>
    </div>
    <?php
}

function khs_footer_code() {

    echo '
<script src="' . plugins_url('shake.js', __FILE__) . '" type="text/javascript"></script>
<div style=" height:0px; width:0px; overflow:hidden;">
<script type="text/javascript">
    jQuery(function () {
        var kkeys = [], konami = "38,38,40,40,37,39,37,39,66,65";
        jQuery(document).keydown(function(e)
        {
            kkeys.push( e.keyCode );
            if ( kkeys.toString().indexOf( konami ) >= 0 )
            {
                jQuery(document).unbind("keydown", arguments.callee);
                harlem_shake("'.plugins_url('', __FILE__).'", "'.get_option('khs_dom_id_first').'");
            }
        });
    });
</script>
</div>
';

}

add_action('wp_footer', 'khs_footer_code');

